options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'yast35missingvars.dat' lrecl=43 missover DSD DLM=' ' print;
input
  R0000100
  Z0543101
  Z0543102
  Z0553301
  Z0553302
  Z0554401
  Z0554402
  Z0558501
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "PUBID - YTH ID CODE 1997";
  label Z0543101 = "LOW RANGE OF AMT OWED ON VEHICLES";
  label Z0543102 = "UP RANGE OF AMT OWED ON VEHICLES";
  label Z0553301 = "ENT LOWER RANGE AMT OTH ESTATE PROP";
  label Z0553302 = "ENT UPPER RANGE AMT OTH ESTATE PROP";
  label Z0554401 = "ENT LOWER RNGE AMT OWED PERS EDUC LOANS";
  label Z0554402 = "ENT UPPER RNGE AMT PERS GOVT EDUC LOANS";
  label Z0558501 = "ENT AMT ALL SP ASSETS/DEBTS (NEG)";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarantee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'PUBID_1997'n
  Z0543101 = 'YAST35-4000S10B_000001_COMB_XRND'n
  Z0543102 = 'YAST35-4000S10B_000002_COMB_XRND'n
  Z0553301 = 'YAST35-4164_000001_COMB_XRND'n
  Z0553302 = 'YAST35-4164_000002_COMB_XRND'n
  Z0554401 = 'YAST35-5013_000001_COMB_XRND'n
  Z0554402 = 'YAST35-5013_000002_COMB_XRND'n
  Z0558501 = 'YAST35-5282N_COMB_XRND'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx0f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
;
value vx1f
  0='0'
  1-4999='1 TO 4999'
  5000-9999='5000 TO 9999'
  10000-14999='10000 TO 14999'
  15000-19999='15000 TO 19999'
  20000-24999='20000 TO 24999'
  25000-29999='25000 TO 29999'
  30000-39999='30000 TO 39999'
  40000-49999='40000 TO 49999'
  50000-59999='50000 TO 59999'
  60000-69999='60000 TO 69999'
  70000-79999='70000 TO 79999'
  80000-89999='80000 TO 89999'
  90000-99999='90000 TO 99999'
  100000-149999='100000 TO 149999'
  150000-99999999='150000 TO 99999999: 150000+'
;
value vx2f
  0='0'
  1-4999='1 TO 4999'
  5000-9999='5000 TO 9999'
  10000-14999='10000 TO 14999'
  15000-19999='15000 TO 19999'
  20000-24999='20000 TO 24999'
  25000-29999='25000 TO 29999'
  30000-39999='30000 TO 39999'
  40000-49999='40000 TO 49999'
  50000-59999='50000 TO 59999'
  60000-69999='60000 TO 69999'
  70000-79999='70000 TO 79999'
  80000-89999='80000 TO 89999'
  90000-99999='90000 TO 99999'
  100000-149999='100000 TO 149999'
  150000-99999999='150000 TO 99999999: 150000+'
;
value vx3f
  -999999--3000='-999999 TO -3000: < -2999'
  -2999--2000='-2999 TO -2000'
  -1999--1000='-1999 TO -1000'
  -999--1='-999 TO -1'
  0='0'
  1-1000='1 TO 1000'
  1001-2000='1001 TO 2000'
  2001-3000='2001 TO 3000'
  3001-5000='3001 TO 5000'
  5001-10000='5001 TO 10000'
  10001-20000='10001 TO 20000'
  20001-30000='20001 TO 30000'
  30001-40000='30001 TO 40000'
  40001-50000='40001 TO 50000'
  50001-65000='50001 TO 65000'
  65001-80000='65001 TO 80000'
  80001-100000='80001 TO 100000'
  100001-150000='100001 TO 150000'
  150001-200000='150001 TO 200000'
  200001-99999999='200001 TO 99999999: 200001+'
;
value vx4f
  -999999--3000='-999999 TO -3000: < -2999'
  -2999--2000='-2999 TO -2000'
  -1999--1000='-1999 TO -1000'
  -999--1='-999 TO -1'
  0='0'
  1-1000='1 TO 1000'
  1001-2000='1001 TO 2000'
  2001-3000='2001 TO 3000'
  3001-5000='3001 TO 5000'
  5001-10000='5001 TO 10000'
  10001-20000='10001 TO 20000'
  20001-30000='20001 TO 30000'
  30001-40000='30001 TO 40000'
  40001-50000='40001 TO 50000'
  50001-65000='50001 TO 65000'
  65001-80000='65001 TO 80000'
  80001-100000='80001 TO 100000'
  100001-150000='100001 TO 150000'
  150001-200000='150001 TO 200000'
  200001-99999999='200001 TO 99999999: 200001+'
;
value vx5f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
  10000-14999='10000 TO 14999'
  15000-19999='15000 TO 19999'
  20000-24999='20000 TO 24999'
  25000-49999='25000 TO 49999'
  50000-99999999='50000 TO 99999999: 50000+'
;
value vx6f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
  10000-14999='10000 TO 14999'
  15000-19999='15000 TO 19999'
  20000-24999='20000 TO 24999'
  25000-49999='25000 TO 49999'
  50000-99999999='50000 TO 99999999: 50000+'
;
value vx7f
  0='0'
  1-1000='1 TO 1000'
  1001-2000='1001 TO 2000'
  2001-3000='2001 TO 3000'
  3001-5000='3001 TO 5000'
  5001-10000='5001 TO 10000'
  10001-20000='10001 TO 20000'
  20001-30000='20001 TO 30000'
  30001-40000='30001 TO 40000'
  40001-50000='40001 TO 50000'
  50001-65000='50001 TO 65000'
  65001-80000='65001 TO 80000'
  80001-100000='80001 TO 100000'
  100001-150000='100001 TO 150000'
  150001-200000='150001 TO 200000'
  200001-99999999='200001 TO 99999999: 200001+'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format R0000100 vx0f.;
  format Z0543101 vx1f.;
  format Z0543102 vx2f.;
  format Z0553301 vx3f.;
  format Z0553302 vx4f.;
  format Z0554401 vx5f.;
  format Z0554402 vx6f.;
  format Z0558501 vx7f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format 'PUBID_1997'n vx0f.;
  format 'YAST35-4000S10B_000001_COMB_XRND'n vx1f.;
  format 'YAST35-4000S10B_000002_COMB_XRND'n vx2f.;
  format 'YAST35-4164_000001_COMB_XRND'n vx3f.;
  format 'YAST35-4164_000002_COMB_XRND'n vx4f.;
  format 'YAST35-5013_000001_COMB_XRND'n vx5f.;
  format 'YAST35-5013_000002_COMB_XRND'n vx6f.;
  format 'YAST35-5282N_COMB_XRND'n vx7f.;
run;
*/